@@ -30,7 +30,7 @@ def main():
     # Get the directory of script and read mapping file
     join("db/gene_db_mapping.tsv")
     # print("Script path:", script)
-    mapping_file = join("db/gene_db_mapping.tsv")
+    mapping_file = join("gene_db_mapping.tsv")
     map_dict = mapping_dict(mapping_file)
 
     # print(input_file)
